@@ -8,7 +8,7 @@ use Fcntl ':flock';
 use Data::Dumper;    # when debugging is on
 use base 'Exporter';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 my %TMPFILE;
 my %LOCK;
 our @EXPORT_OK = qw(getDir lock lock_ex lock_sh unlock lockobj lockobj_ex
@@ -57,7 +57,7 @@ sub lock_ex {
             $P && print STDERR "$P timeout waiting for lock\n";
             return;
         }
-        Time::HiRes::sleep 0.3 + 2 * rand() * $PAUSE_LENGTH;
+        Time::HiRes::sleep $PAUSE_LENGTH * (1 + 2 * rand());
         if (Time::HiRes::time > $last_check + $HEARTBEAT_CHECK) {
             $P && print STDERR "$P check heartbeat of lock holder\n";
             _ping_oldest_file($dir);
@@ -89,7 +89,7 @@ sub lock_sh {
             $P && print STDERR "$P timeout waiting for lock\n";
             return;
         }
-        Time::HiRes::sleep 0.3 + 2 * rand() * $PAUSE_LENGTH;
+        Time::HiRes::sleep $PAUSE_LENGTH * (1 + 2 * rand());
         if (Time::HiRes::time > $last_check + $HEARTBEAT_CHECK) {
             $P && print STDERR "$P check heartbeat of lock holder\n";
             _ping_oldest_file($dir);
@@ -152,7 +152,6 @@ sub unlock {
     my $z = unlink($filename);
     if ($z) {
 	$_DEBUG && print STDERR _pid()," deleted $filename\n";
-	$_DEBUG && print STDERR "$dir contains:\n",join(" ",glob("$dir/*")),"\n";
 	delete $TMPFILE{$filename};
 	return $z;
     }
@@ -358,7 +357,7 @@ Dir::Flock - advisory locking of a dedicated directory
 
 =head1 VERSION
 
-0.07
+0.08
 
 
 
